import logging


class Colors:
    grey = "\x1b[0;37m"
    green = "\x1b[1;32m"
    yellow = "\x1b[1;33m"
    red = "\x1b[1;31m"
    purple = "\x1b[1;35m"
    blue = "\x1b[1;34m"
    light_blue = "\x1b[1;36m"
    reset = "\x1b[0m"
    blink_red = "\x1b[5m\x1b[1;31m"


class ColorFormatter(logging.Formatter):
    """Logging Formatter to add colors and count warning / errors"""

    def __init__(self, auto_colorized=True, custom_format: str = None):
        super(ColorFormatter, self).__init__()
        self.auto_colorized = auto_colorized
        self.custom_format = custom_format
        self.FORMATS = self.define_format()

    def define_format(self):
        format_prefix = f"{Colors.light_blue}%(asctime)s " f"%(name)s{Colors.reset} "
        # f"(%(filename)s:%(lineno)d){Colors.reset} "

        format_suffix = f"%(levelname)s{Colors.reset} - %(message)s"

        return {
            logging.DEBUG: format_prefix + Colors.blue + format_suffix + Colors.reset,
            logging.INFO: format_prefix
            + Colors.light_blue
            + format_suffix
            + Colors.reset,
            logging.WARNING: format_prefix
            + Colors.yellow
            + format_suffix
            + Colors.reset,
            logging.ERROR: format_prefix + Colors.red + format_suffix + Colors.reset,
            logging.CRITICAL: format_prefix
            + Colors.blink_red
            + format_suffix
            + Colors.reset,
        }

    def format(self, record):
        log_fmt = self.FORMATS.get(record.levelno)
        formatter = logging.Formatter(log_fmt)
        return formatter.format(record)


# Configure logging


def setColoredLogger(logger: logging.Logger):
    logging.basicConfig(level=logging.INFO)
    loggingStream = logging.StreamHandler()
    loggingStream.setLevel(logging.DEBUG)
    loggingStream.setFormatter(ColorFormatter())
    logger.addHandler(loggingStream)
    logger.propagate = False
    return logger


def init(defaultLevel):
    logging.getLogger().setLevel(defaultLevel)


def getLogger(name):
    logger = logging.getLogger(name)
    return setColoredLogger(logger)



from isaac_analyzer.yaml_loader import load_yaml_resource


def test_load_yaml():
    data = load_yaml_resource("items.yaml")
    assert isinstance(data, dict)
    assert "items" in data  # Replace with actual checks based on your YAML structure



import os
import yaml
from importlib.resources import files


def load_yaml(filename):
    """Load YAML file into a dictionary from the resource folder."""
    yaml_path = os.path.join("resources", filename)
    with open(yaml_path, "r") as file:
        data = yaml.safe_load(file)
    return data


def load_yaml_full_path(file_path):
    """Load YAML file into a dictionary from a given path."""
    with open(file_path, "r") as file:
        data = yaml.safe_load(file)
    return data


def load_yaml_resource(name):
    """Load YAML file into a dictionary from a resource name."""
    with files("isaac_analyzer").joinpath(f"resources/{name}").open() as file:
        data = yaml.safe_load(file)
    return data



import subprocess


def test_version():
    result = subprocess.run(
        ["isaac-analyzer", "--version"], capture_output=True, text=True
    )
    assert result.returncode == 0
    assert "isaac-analyzer 0.1.16" in result.stdout



from setuptools import setup, find_packages

setup(
    name="isaac-analyzer",
    version="0.1.16",
    packages=find_packages(),
    package_data={"isaac_analyzer": ["resources/*"]},
    install_requires=["pyyaml", "tabulate", "jsonschema"],
    entry_points={
        "console_scripts": [
            "isaac-analyzer=isaac_analyzer.cli:main",
        ],
    },
    author="Supporterino",
    author_email="lars@roth-kl.de",
    description="A CLI application to analyze isaac runs documented in YAML",
    long_description=open("README.md").read(),
    long_description_content_type="text/markdown",
    url="https://git.roth-kl.de/isaac/isaac-analyzer",
    include_package_data=True,
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    python_requires=">=3.9",
)
